namespace TestReports
{
    using System;
    using System.ComponentModel;
    using System.Drawing;
    using System.Data;
    using System.Text;
    using System.Windows.Forms;
    using Telerik.Reporting;
    using Telerik.Reporting.Drawing;
    using Telerik.Reporting.Charting;
    using System.IO;
    using System.Linq;
    using System.Reflection;
    using System.Xml.Linq;
    using System.Configuration;

    /// <summary>
    /// Summary description for Report.
    /// </summary>
    public partial class Test : Telerik.Reporting.Report
    {
        #region Fields

        private string xmlString;

        #endregion Fields

        public Test()
        {
            
            InitializeComponent();

        }

        public void SaveReport(string xmlInput, string exportFormat, string exportPath, string logoLocation)
        {
            //Assign the xml data to use for the report
            xmlString = xmlInput;

            //Assign the full document name
            this.DocumentName = exportPath;

            //Save the file to the specified location
            ExportToFile(this.Report, exportFormat, exportPath);
        }


        private void ExportToFile(Telerik.Reporting.Report reportToExport, string exportFormat, string exportPath)
        {
            Telerik.Reporting.Processing.ReportProcessor reportProcessor = new Telerik.Reporting.Processing.ReportProcessor();
            Telerik.Reporting.Processing.RenderingResult result = reportProcessor.RenderReport(exportFormat, reportToExport, null);

            string fileName = result.DocumentName;// +"." + exportFormat.ToLower();

            File.WriteAllBytes(fileName, result.DocumentBytes);
        }

        private void Pie_NeedDataSource(object sender, EventArgs e)
        {

            Telerik.Reporting.Processing.Chart chart = sender as Telerik.Reporting.Processing.Chart;
           
            Telerik.Reporting.Chart chartDef = (Telerik.Reporting.Chart)chart.ItemDefinition;
            Telerik.Reporting.Charting.ChartSeries series = new Telerik.Reporting.Charting.ChartSeries();
            series.Type = ChartSeriesType.Pie;
            Telerik.Reporting.Charting.ChartLegend legend = new Telerik.Reporting.Charting.ChartLegend();

            string CoverDescription;
            double itemValue;

            // Read the embedded XML file
            var assembly = Assembly.GetExecutingAssembly();
            var stream = assembly.GetManifestResourceStream("ClassLibrary1.Data.Report.xml");
            var xml = XDocument.Load(new StreamReader(stream));

            //Read the data from inputted XML string
            //var xml = XDocument.Load(new StringReader(xmlString));

            // Query the XML data
            var cover1 = from c in xml.Descendants("CoverBreakdown")
                             select new CoverBreakDownDS
                             {
                                 Description = c.Element("Description").Value,
                                 Value = Convert.ToDouble(c.Element("Value").Value),
                             };

            foreach (CoverBreakDownDS rowView in cover1.ToList<CoverBreakDownDS>())
            {
                Telerik.Reporting.Charting.ChartSeriesItem seriesItem = new Telerik.Reporting.Charting.ChartSeriesItem();
                
                //The chart Y value will be based on the Value amount 
                seriesItem.YValue = Convert.ToDouble(rowView.Value);
                seriesItem.Appearance.FillStyle.FillType = Telerik.Reporting.Charting.Styles.FillType.Solid;
                
                //The chart item label should be set to the Value amount 
                itemValue = Convert.ToDouble(rowView.Value);
                seriesItem.Label.TextBlock.Text = itemValue.ToString("##,###.00");
                seriesItem.Label.Appearance.LabelLocation = Telerik.Reporting.Charting.Styles.StyleSeriesItemLabel.ItemLabelLocation.Inside;
                seriesItem.Label.TextBlock.Appearance.TextProperties.Color = System.Drawing.Color.FromArgb(((int)(((byte)(28)))), ((int)(((byte)(58)))), ((int)(((byte)(112)))));

                //Assign the chart item description
                CoverDescription = rowView.Description;
                seriesItem.Name = CoverDescription.Trim();
                
                //Give the "Shortfall in Cover" chart item an exploded appearance
                if (seriesItem.Name == "Shortfall In Cover")
                {
                    seriesItem.Appearance.Exploded = true;
                }

                series.AddItem(seriesItem);

            }
            
            //Display the legend
            series.Appearance.LegendDisplayMode = ChartSeriesLegendDisplayMode.ItemLabels;
            series.Appearance.Border.Color = System.Drawing.Color.White;
            series.Appearance.Border.Visible = false;
            series.Appearance.DiameterScale = .90;
            
            series.Appearance.ExplodePercent = 10;
                        
            chartDef.Series.Clear();
            chartDef.Series.Add(series);

            chartDef.Legend.Appearance.Position.AlignedPosition = Telerik.Reporting.Charting.Styles.AlignedPositions.TopRight;

        }

        

        private void Quotes_NeedDataSource(object sender, System.EventArgs e)
        {

            // Read the embedded XML file
            var assembly = Assembly.GetExecutingAssembly();
            var stream = assembly.GetManifestResourceStream("ClassLibrary1.Data.Report.xml");
            var xml = XDocument.Load(new StreamReader(stream));

            //Read the data from inputted XML string
            //var xml = XDocument.Load(new StringReader(xmlString));

            // Query the XML data
            var quotes = from c in xml.Descendants("Quote")
                                select new QuotesDS
                                {
                                    Company = c.Element("Company").Value,
                                    RateType = c.Element("RateType").Value,
                                    Benefit1 = Convert.ToDouble(c.Element("Benefit1").Value),
                                    Benefit2 = Convert.ToDouble(c.Element("Benefit2").Value),
                                };
            (sender as Telerik.Reporting.Processing.Table).DataSource = quotes.ToList<QuotesDS>();
        }

      
        
        
    }
}